==> puppet-module-cinder_17.4.0.orig.tar.xz: puppet-module-cinder-17.4.0/spec/unit/type/cinder_config_spec.rb <==
require 'puppet'
require 'puppet/type/cinder_config'

describe 'Puppet::Type.type(:cinder_config)' do
  before :each do
    @cinder_config = Puppet::Type.type(:cinder_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

  it 'should require a name' do
    expect {
      Puppet::Type.type(:cinder_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:cinder_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:cinder_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:cinder_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @cinder_config[:value] = 'bar'
    expect(@cinder_config[:value]).to eq('bar')
  end

  it 'should not accept a value with whitespace' do
    @cinder_config[:value] = 'b ar'
    expect(@cinder_config[:value]).to eq('b ar')
  end

  it 'should accept valid ensure values' do
    @cinder_config[:ensure] = :present
    expect(@cinder_config[:ensure]).to eq(:present)
    @cinder_config[:ensure] = :absent
    expect(@cinder_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @cinder_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    anchor = Puppet::Type.type(:anchor).new(:name => 'cinder::install::end')
    catalog.add_resource anchor, @cinder_config
    dependency = @cinder_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@cinder_config)
    expect(dependency[0].source).to eq(anchor)
  end

end

==> puppet-module-cinder_19.4.0.orig.tar.xz: puppet-module-cinder-19.4.0/spec/unit/type/cinder_config_spec.rb <==
require 'puppet'
require 'puppet/type/cinder_config'

describe 'Puppet::Type.type(:cinder_config)' do
  before :each do
    @cinder_config = Puppet::Type.type(:cinder_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

  it 'should require a name' do
    expect {
      Puppet::Type.type(:cinder_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:cinder_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:cinder_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:cinder_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @cinder_config[:value] = 'bar'
    expect(@cinder_config[:value]).to eq(['bar'])
  end

  it 'should not accept a value with whitespace' do
    @cinder_config[:value] = 'b ar'
    expect(@cinder_config[:value]).to eq(['b ar'])
  end

  it 'should accept valid ensure values' do
    @cinder_config[:ensure] = :present
    expect(@cinder_config[:ensure]).to eq(:present)
    @cinder_config[:ensure] = :absent
    expect(@cinder_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @cinder_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    anchor = Puppet::Type.type(:anchor).new(:name => 'cinder::install::end')
    catalog.add_resource anchor, @cinder_config
    dependency = @cinder_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@cinder_config)
    expect(dependency[0].source).to eq(anchor)
  end

end
